## cdist-type__apt_norecommends(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__apt_norecommends - configure apt to not install recommended packages

## 2. DESCRIPTION

Configure apt to not install any recommended or suggested packages.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

None.

## 5. EXAMPLES

    __apt_norecommends

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).